<?php
/**
 * Twenty Minutes Theme Customizer
 *
 * @package Twenty Minutes
 */

get_template_part('/inc/select/category-dropdown-custom-control');

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function twenty_minutes_customize_register( $wp_customize ) {

	function twenty_minutes_sanitize_phone_number( $phone ) {
		return preg_replace( '/[^\d+]/', '', $phone );
	}

	function twenty_minutes_sanitize_email( $email, $setting ) {
		// Strips out all characters that are not allowable in an email address.
		$email = sanitize_email( $email );
		
		// If $email is a valid email, return it; otherwise, return the default.
		return ( ! is_null( $email ) ? $email : $setting->default );
	}

	function twenty_minutes_sanitize_checkbox( $checked ) {
		// Boolean check.
		return ( ( isset( $checked ) && true == $checked ) ? true : false );
	}

	function twenty_minutes_sanitize_number_absint( $number, $setting ) {
		// Ensure $number is an absolute integer (whole number, zero or greater).
		$number = absint( $number );
		
		// If the input is an absolute integer, return it; otherwise, return the default
		return ( $number ? $number : $setting->default );
	}

	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';

	//Theme Options
	$wp_customize->add_panel( 'twenty_minutes_panel_area', array(
		'priority' => null,
		'capability' => 'edit_theme_options',
		'title' => __( 'Theme Options Panel', 'twenty-minutes' ),
	) );
	
	//Site Layout Section
	$wp_customize->add_section('twenty_minutes_site_layoutsec',array(
		'title'	=> __('Site Layout','twenty-minutes'),
		'priority'	=> 1,
		'panel' => 'twenty_minutes_panel_area',
	));		
	
	$wp_customize->add_setting('twenty_minutes_box_layout',array(
		'sanitize_callback' => 'twenty_minutes_sanitize_checkbox',
	));	 

	$wp_customize->add_control( 'twenty_minutes_box_layout', array(
	   'section'   => 'twenty_minutes_site_layoutsec',
	   'label'	=> __('Check to Box Layout','twenty-minutes'),
	   'type'      => 'checkbox'
 	)); 

 	// Header Section
	$wp_customize->add_section('twenty_minutes_header_section', array(
        'title' => __('Header Section', 'twenty-minutes'),
        'priority' => null,
		'panel' => 'twenty_minutes_panel_area',
 	));

	$wp_customize->add_setting('twenty_minutes_phone_number',array(
		'default' => '',
		'sanitize_callback' => 'twenty_minutes_sanitize_phone_number',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'twenty_minutes_phone_number', array(
	   'settings' => 'twenty_minutes_phone_number',
	   'section'   => 'twenty_minutes_header_section',
	   'label' => __('Add Phone Number', 'twenty-minutes'),
	   'type'      => 'text'
	));

	$wp_customize->add_setting('twenty_minutes_email_address',array(
		'default' => '',
		'sanitize_callback' => 'twenty_minutes_sanitize_email',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'twenty_minutes_email_address', array(
	   'settings' => 'twenty_minutes_email_address',
	   'section'   => 'twenty_minutes_header_section',
	   'label' => __('Add Email Address', 'twenty-minutes'),
	   'type'      => 'text'
	));

	// Social media Section
	$wp_customize->add_section('twenty_minutes_social_media_section', array(
        'title' => __('Social media Section', 'twenty-minutes'),
        'priority' => null,
		'panel' => 'twenty_minutes_panel_area',
 	));

	$wp_customize->add_setting('twenty_minutes_fb_link',array(
		'default' => '',
		'sanitize_callback' => 'esc_url_raw',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'twenty_minutes_fb_link', array(
	   'settings' => 'twenty_minutes_fb_link',
	   'section'   => 'twenty_minutes_social_media_section',
	   'label' => __('Facebook Link', 'twenty-minutes'),
	   'type'      => 'url'
	));

	$wp_customize->add_setting('twenty_minutes_twitt_link',array(
		'default' => '',
		'sanitize_callback' => 'esc_url_raw',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'twenty_minutes_twitt_link', array(
	   'settings' => 'twenty_minutes_twitt_link',
	   'section'   => 'twenty_minutes_social_media_section',
	   'label' => __('Twitter Link', 'twenty-minutes'),
	   'type'      => 'url'
	));

	$wp_customize->add_setting('twenty_minutes_linked_link',array(
		'default' => '',
		'sanitize_callback' => 'esc_url_raw',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'twenty_minutes_linked_link', array(
	   'settings' => 'twenty_minutes_linked_link',
	   'section'   => 'twenty_minutes_social_media_section',
	   'label' => __('Linkdin Link', 'twenty-minutes'),
	   'type'      => 'url'
	));

	$wp_customize->add_setting('twenty_minutes_insta_link',array(
		'default' => '',
		'sanitize_callback' => 'esc_url_raw',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'twenty_minutes_insta_link', array(
	   'settings' => 'twenty_minutes_insta_link',
	   'section'   => 'twenty_minutes_social_media_section',
	   'label' => __('Instagram Link', 'twenty-minutes'),
	   'type'      => 'url'
	));

	$wp_customize->add_setting('twenty_minutes_youtube_link',array(
		'default' => '',
		'sanitize_callback' => 'esc_url_raw',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'twenty_minutes_youtube_link', array(
	   'settings' => 'twenty_minutes_youtube_link',
	   'section'   => 'twenty_minutes_social_media_section',
	   'label' => __('Youtube Link', 'twenty-minutes'),
	   'type'      => 'url'
	));

	// Home Category Dropdown Section
	$wp_customize->add_section('twenty_minutes_one_cols_section',array(
		'title'	=> __('Manage Slider','twenty-minutes'),
		'description'	=> __('Select Category from the Dropdowns for slider, Also use the given image dimension (1200 x 450).','twenty-minutes'),
		'priority'	=> null,
		'panel' => 'twenty_minutes_panel_area'
	));

	// Add a category dropdown Slider Coloumn
	$wp_customize->add_setting( 'twenty_minutes_slidersection', array(
		'default'	=> '0',	
		'sanitize_callback'	=> 'absint'
	) );
	$wp_customize->add_control( new Twenty_Minutes_Category_Dropdown_Custom_Control( $wp_customize, 'twenty_minutes_slidersection', array(
		'section' => 'twenty_minutes_one_cols_section',
		'settings'   => 'twenty_minutes_slidersection',
	) ) );

	$wp_customize->add_setting('twenty_minutes_button_text',array(
		'default' => '',
		'sanitize_callback' => 'sanitize_text_field',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'twenty_minutes_button_text', array(
	   'settings' => 'twenty_minutes_button_text',
	   'section'   => 'twenty_minutes_one_cols_section',
	   'label' => __('Add Button Text', 'twenty-minutes'),
	   'type'      => 'text'
	));
	
	//Hide Section
	$wp_customize->add_setting('twenty_minutes_hide_categorysec',array(
		'default' => true,
		'sanitize_callback' => 'twenty_minutes_sanitize_checkbox',
		'capability' => 'edit_theme_options',
	));	 

	$wp_customize->add_control( 'twenty_minutes_hide_categorysec', array(
	   'settings' => 'twenty_minutes_hide_categorysec',
	   'section'   => 'twenty_minutes_one_cols_section',
	   'label'     => __('Uncheck To Enable This Section','twenty-minutes'),
	   'type'      => 'checkbox'
	));

	// Service Section
	$wp_customize->add_section('twenty_minutes_two_cols_section',array(
		'title'	=> __('Manage Service Section','twenty-minutes'),
		'description'	=> __('Select the post category to show services.','twenty-minutes'),
		'priority'	=> null,
		'panel' => 'twenty_minutes_panel_area'
	));
	
	$wp_customize->add_setting('twenty_minutes_section_text',array(
		'default' => '',
		'sanitize_callback' => 'sanitize_text_field',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'twenty_minutes_section_text', array(
	   'settings' => 'twenty_minutes_section_text',
	   'section'   => 'twenty_minutes_two_cols_section',
	   'label'     => __('Add Section Text','twenty-minutes'),
	   'type'      => 'text'
	));

	$wp_customize->add_setting('twenty_minutes_section_title',array(
		'default' => '',
		'sanitize_callback' => 'sanitize_text_field',
		'capability' => 'edit_theme_options',
	));
	$wp_customize->add_control( 'twenty_minutes_section_title', array(
	   'settings' => 'twenty_minutes_section_title',
	   'section'   => 'twenty_minutes_two_cols_section',
	   'label'     => __('Add Section Title','twenty-minutes'),
	   'type'      => 'text'
	));

	// Add a category dropdown Slider Coloumn
	$wp_customize->add_setting( 'twenty_minutes_services_section', array(
		'default'	=> '0',	
		'sanitize_callback'	=> 'absint'
	) );
	$wp_customize->add_control( new Twenty_Minutes_Category_Dropdown_Custom_Control( $wp_customize, 'twenty_minutes_services_section', array(
		'section' => 'twenty_minutes_two_cols_section',
		'settings'   => 'twenty_minutes_services_section',
	) ) );

	// Footer Section 
	$wp_customize->add_section('twenty_minutes_footer', array(
		'title'	=> __('Footer Section','twenty-minutes'),
		'priority'	=> null,
		'panel' => 'twenty_minutes_panel_area',
	));

	$wp_customize->add_setting('twenty_minutes_copyright_line',array(
		'sanitize_callback' => 'sanitize_text_field',
	));	
	$wp_customize->add_control( 'twenty_minutes_copyright_line', array(
	   'section' 	=> 'twenty_minutes_footer',
	   'label'	 	=> __('Copyright Line','twenty-minutes'),
	   'type'    	=> 'text',
	   'priority' 	=> null,
    ));
}
add_action( 'customize_register', 'twenty_minutes_customize_register' );

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function twenty_minutes_customize_preview_js() {
	wp_enqueue_script( 'twenty_minutes_customizer', esc_url(get_template_directory_uri()) . '/js/customize-preview.js', array( 'customize-preview' ), '20161510', true );
}
add_action( 'customize_preview_init', 'twenty_minutes_customize_preview_js' );